@@ -1,4 +1,4 @@
 from pm4pydistr.log_handlers.parquet_filtering.versions import start_activities, end_activities, attributes_pos_trace, \
     attributes_neg_trace, attributes_pos_events, attributes_neg_events, timestamp_events, timestamp_trace_containing, \
     timestamp_trace_intersecting, case_performance_filter, numeric_attr_events, numeric_attr_traces, paths_pos_trace, \
-    paths_neg_trace
+    paths_neg_trace, ltl
